GoogleSearch_services_types.urn_GoogleSearch.DirectoryCategoryArray_Def

|  | ## Cheshire3 Object Model: Class DirectoryCategoryArray_Def

Module GoogleSearch_services_types :: Class urn_GoogleSearch :: Class DirectoryCategoryArray_Def

## Class DirectoryCategoryArray_Def
source code

Object Tree:

         TC.TypeCode --+
                       |
    ZSI.TCcompound.Array --+
                           |
                          DirectoryCategoryArray_Def

Instance Methods

__init__(self, name=None, ns=None, **kw) Baseclass initialization.
Inherited from `ZSI.TCcompound.Array`: `parse`, `parse_offset`, `parse_position`, `serialize` Inherited from `ZSI.TC.TypeCode`: `SimpleHREF`, `checkname`, `checktype`, `get_parse_and_errorlist`, `name_match`, `nilled`, `simple_value`

Class Variables

Inherited from `ZSI.TC.TypeCode`: `typechecks`

Method Details

### __init__(self, name=None, ns=None, **kw) (Constructor) | source code
    Baseclass initialization.
    Instance data (and usually keyword arg)
        pname -- the parameter name (localname).
        nspname -- the namespace for the parameter;
            None to ignore the namespace
        oname -- output name
        ons -- the namespace prefix of the oname
        typed -- output xsi:type attribute
        repeatable -- element can appear more than once
        optional -- the item is optional
        default -- default value
        unique -- data item is not aliased (no href/id needed)
Overrides: ZSI.TCcompound.Array.__init__